# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src',
 'weecfg': 'src/weecfg',
 'weectllib': 'src/weectllib',
 'weedb': 'src/weedb',
 'weeimport': 'src/weeimport',
 'weeplot': 'src/weeplot',
 'weeutil': 'src/weeutil',
 'weewx': 'src/weewx',
 'weewx.drivers': 'src/weewx/drivers',
 'weewx_data': 'src/weewx_data',
 'weewx_data.bin.user': 'src/weewx_data/bin/user',
 'weewx_data.examples': 'src/weewx_data/examples',
 'weewx_data.examples.basic': 'src/weewx_data/examples/basic',
 'weewx_data.examples.colorize': 'src/weewx_data/examples/colorize',
 'weewx_data.examples.fileparse': 'src/weewx_data/examples/fileparse',
 'weewx_data.examples.fileparse.bin.user': 'src/weewx_data/examples/fileparse/bin/user',
 'weewx_data.examples.pmon': 'src/weewx_data/examples/pmon',
 'weewx_data.examples.pmon.bin.user': 'src/weewx_data/examples/pmon/bin/user',
 'weewx_data.examples.xstats': 'src/weewx_data/examples/xstats',
 'weewx_data.examples.xstats.bin.user': 'src/weewx_data/examples/xstats/bin/user'}

packages = \
['schemas',
 'weecfg',
 'weectllib',
 'weedb',
 'weeimport',
 'weeplot',
 'weeutil',
 'weewx',
 'weewx.drivers',
 'weewx_data',
 'weewx_data.bin.user',
 'weewx_data.examples',
 'weewx_data.examples.basic',
 'weewx_data.examples.colorize',
 'weewx_data.examples.fileparse',
 'weewx_data.examples.fileparse.bin.user',
 'weewx_data.examples.pmon',
 'weewx_data.examples.pmon.bin.user',
 'weewx_data.examples.xstats',
 'weewx_data.examples.xstats.bin.user']

package_data = \
{'': ['*'],
 'weewx_data': ['scripts/*',
                'skins/Ftp/*',
                'skins/Mobile/*',
                'skins/Mobile/lang/*',
                'skins/Rsync/*',
                'skins/Seasons/*',
                'skins/Seasons/NOAA/*',
                'skins/Seasons/font/*',
                'skins/Seasons/lang/*',
                'skins/Smartphone/*',
                'skins/Smartphone/icons/*',
                'skins/Smartphone/lang/*',
                'skins/Standard/*',
                'skins/Standard/NOAA/*',
                'skins/Standard/RSS/*',
                'skins/Standard/backgrounds/*',
                'skins/Standard/font/*',
                'skins/Standard/lang/*',
                'skins/Standard/smartphone/*',
                'skins/Standard/smartphone/icons/*',
                'util/apache/*',
                'util/default/*',
                'util/i18n/*',
                'util/import/*',
                'util/init.d/*',
                'util/launchd/*',
                'util/logrotate.d/*',
                'util/logwatch/conf/logfiles/*',
                'util/logwatch/conf/services/*',
                'util/logwatch/scripts/services/*',
                'util/newsyslog.d/*',
                'util/nginx/*',
                'util/rsyslog.d/*',
                'util/solaris/*',
                'util/systemd/*',
                'util/tmpfiles.d/*',
                'util/udev/rules.d/*'],
 'weewx_data.examples.basic': ['skins/Basic/*', 'skins/Basic/lang/*'],
 'weewx_data.examples.pmon': ['skins/pmon/*'],
 'weewx_data.examples.xstats': ['skins/xstats/*']}

modules = \
['weectl', 'weewxd']
install_requires = \
['CT3>=3.1,<4.0',
 'Pillow>=5.2',
 'PyMySQL>=1.0,<2.0',
 'configobj>=5.0,<6.0',
 'ephem>=4.1,<5.0',
 'pyserial>=3.4,<4.0',
 'pyusb>=1.0.2,<2.0.0']

entry_points = \
{'console_scripts': ['weectl = weectl:main', 'weewxd = weewxd:main']}

setup_kwargs = {
    'name': 'weewx',
    'version': '5.0.0b17',
    'description': 'The WeeWX weather software system. This is an BETA release, and may have many bugs!',
    'long_description': '![CI workflow](https://github.com/weewx/weewx/actions/workflows/ci.yaml/badge.svg)\n[![Poetry](https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json)](https://python-poetry.org/)\n\n# [WeeWX](https://www.weewx.com)\n*Open source software for your weather station*\n\n## Description\n\nThe WeeWX weather system is written in Python and runs on Linux, MacOSX,\nSolaris, and *BSD.  It runs exceptionally well on a Raspberry Pi.  It collects\ndata from many different types of weather stations and sensors, then generates\nplots, HTML pages, and monthly and yearly summary reports. It can push plots,\npages, and reports to a web server, as well as upload weather-related data to \nmany online weather services.  Thousands of users worldwide!\n\nSee the WeeWX website for [examples](https://weewx.com/showcase.html) of\nwebsites generated by WeeWX, and a [map](https://weewx.com/stations.html) of\nstations using WeeWX.\n\n* Robust and hard-to-crash\n* Designed with the enthusiast in mind\n* Simple internal design that is easily extended (Python skills recommended)\n* Large ecosystem of 3rd party extensions\n* Internationalized language support\n* Localized date/time support\n* Support for US and metric units\n* Support for multiple skins\n* Support for sqlite and MySQL\n* Extensive almanac information\n* Uploads to your website via FTP, FTPS, or rsync\n* Uploads to online weather services\n* Requires Python 3.7 or greater\n\nSupport for many online weather services, including:\n\n* The Weather Underground\n* CWOP\n* PWSweather\n* WOW\n* AWEKAS\n* Windy\n* Open Weathermap\n* WeatherBug\n* Weather Cloud\n* Wetter\n* Windfinder\n\nSupport for many data publishing and aggregation services, including:\n\n* MQTT\n* InfluxDB\n\nSupport for over 70 types of hardware including, but not limited to:\n\n* Davis Vantage Pro, Pro2, Vue, Envoy;\n* Oregon Scientific WMR100, WMR300, WMR9x8, and other variants;\n* Oregon Scientific LW300/LW301/LW302;\n* Fine Offset WH10xx, WH20xx, and WH30xx series (including Ambient, Elecsa, Maplin, Tycon, Watson, and others);\n* Fine Offset WH23xx, WH4000 (including Tycon TP2700, MiSol WH2310);\n* Fine Offset WH2600, HP1000 (including Ambient Observer, Aercus WeatherSleuth, XC0422);\n* LaCrosse WS-23XX and WS-28XX (including TFA);\n* LaCrosse GW1000U bridge;\n* Hideki TE923, TE831, TE838, DV928 (including TFA, Cresta, Honeywell, and others);\n* PeetBros Ultimeter;\n* RainWise CC3000 and MKIII;\n* AcuRite 5-in-1 via USB console or bridge;\n* AcuRite Atlas;\n* Argent Data Systems WS1;\n* KlimaLogg Pro;\n* New Mountain;\n* AirMar 150WX;\n* Texas Weather Instruments;\n* Dyacon;\n* Meteostick;\n* Ventus W820;\n* Si1000 radio receiver;\n* Software Defined Radio (SDR);\n* One-wire (including Inspeed, ADS, AAG, Hobby-Boards).\n\nSee the [hardware list](https://www.weewx.com/hardware.html) for a complete\nlist of supported stations, and for pictures to help identify your hardware!\nThe [hardware comparison](https://www.weewx.com/hwcmp.html) has specifications\nfor many different types of hardware, including some not yet supported by\nWeeWX.\n\n## Install\n\n[https://weewx.com/docs/5.0/quickstarts](https://weewx.com/docs/5.0/quickstarts)\n\n## Download\n\nFor current and previous releases:\n\n[https://weewx.com/downloads](https://weewx.com/downloads)\n\nFor the latest source code:\n\n[https://github.com/weewx/weewx](https://github.com/weewx/weewx)\n\n## Documentation and Support\n\nGuides for installation, upgrading, and customization:\n\n[https://weewx.com/docs/5.0/](https://weewx.com/docs/5.0/)\n\nThe wiki includes user-contributed extensions and suggestions:\n\n[https://github.com/weewx/weewx/wiki](https://github.com/weewx/weewx/wiki)\n\nCommunity support can be found at:\n\n[https://groups.google.com/group/weewx-user](https://groups.google.com/group/weewx-user)\n\n## Licensing\n\nWeeWX is licensed under the GNU Public License v3.\n\n## Copyright\n\n© 2009-2023 Thomas Keffer, Matthew Wall, and Gary Roderick\n',
    'author': 'Tom Keffer',
    'author_email': 'tkeffer@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://weewx.com',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'py_modules': modules,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
